@@ -140,7 +140,7 @@ class SchedulerForm(forms.ModelForm):
         model = Scheduler
         fields = ('routine', 'is_active', 'language',
                   'content_type', 'fields',
-                  'format', 'context',
+                  'format', 'context', 'exporter_path',
                   'query_string', 'recipients')
         widgets = {
             'query_string': TextInput,
@@ -161,6 +161,7 @@ class SchedulerForm(forms.ModelForm):
                         Div('content_type', css_class='col-md-4'),
                         Div('context', css_class='col-md-4'),
                         Div('format', css_class='col-md-4'),
+                        Div('exporter_path', css_class='col-md-12'),
                         Div('query_string', css_class='col-md-12'),
                         Div('fields', css_class='col-md-12'),
                     ),
@@ -190,7 +191,7 @@ class SchedulerForm(forms.ModelForm):
 
             try:
                 # validation of content_type, context and format (check if exporter exists)
-                AbstractExport.get_exporter_class(model_class, context, format)
+                AbstractExport.get_exporter_path(model_class, context, format)
             except ImportError:
                 self.add_error(None, _('Exporter for content type {} with given context and format is not available').format(content_type))
 
