@@ -11,7 +11,7 @@ from django.db import models
 from django.http import QueryDict
 from django.template import Context, Template
 from django.template.defaultfilters import title
-from django.urls import reverse
+from django.urls import reverse, NoReverseMatch, resolve, Resolver404
 from django.utils.module_loading import import_string
 from django.utils.translation import ugettext_lazy as _
 from gm2m import GM2MField
@@ -52,6 +52,7 @@ class AbstractExport(models.Model):
     content_type = models.ForeignKey(ContentType, verbose_name=_('content type'), on_delete=models.CASCADE)
     format = models.CharField(_('format'), choices=FORMATS, max_length=7)
     context = models.CharField(_('context'), choices=CONTEXTS, max_length=10)
+    exporter_path = models.CharField(_('exporter path'), max_length=100, blank=True, default='')
     fields = ArrayField(verbose_name=_('fields'), base_field=models.CharField(max_length=40), blank=True, null=True, default=None)
     query_string = models.TextField(_('query string'), blank=True, default='')
     creator = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name=_('creator'), on_delete=models.PROTECT, related_name="%(class)s_where_creator",
@@ -69,7 +70,10 @@ class AbstractExport(models.Model):
         return self.content_type.model_class()
 
     @staticmethod
-    def get_exporter_class(model_class, context, format):
+    def get_exporter_path(model_class, context, format):
+        """
+        Returns generic exporter path based on content object model, export context and format.
+        """
         exports_module = exporters_module_mapping.get(model_class._meta.label, None)
 
         if isinstance(exports_module, dict):
@@ -86,11 +90,24 @@ class AbstractExport(models.Model):
         context = title(context)
         exporter_class_name = '{}{}{}Exporter'.format(exporter_class_name, format, context)
         exporter_path = f'{exports_module}.{exporter_class_name}'
-        return import_string(exporter_path)
+        return exporter_path
 
     @property
     def exporter_class(self):
-        return AbstractExport.get_exporter_class(self.model_class, self.context, self.format)
+        try:
+            if self.exporter_path:
+                return import_string(self.exporter_path)
+            else:
+                raise ModuleNotFoundError()
+        except ModuleNotFoundError:
+            # TODO: log
+            exporter_path = AbstractExport.get_exporter_path(
+                model_class=self.model_class,
+                context=self.context,
+                format=self.format
+            )
+            print('ERROR: Exporter path %s not found. Using fallback (predicted path) instead: %s' % (self.exporter_path, exporter_path))
+            return import_string(exporter_path)
 
     @property
     def exporter(self):
@@ -127,16 +144,21 @@ class AbstractExport(models.Model):
     def get_params_display(self):
         result = ''
 
-        filter = self.exporter.filter
+        try:
+            filter = self.exporter.filter
+            values = filtered_values(filter, self.params)
 
-        filter_values = filtered_values(filter, self.params)
+            for param, field in values.items():
+                label = field['label']
+                value = field['value']
 
-        for param, field in filter_values.items():
-            label = field['label']
-            value = field['value']
+                value = Template("{{ value }}").render(Context({'value': value}))  # workaround for datetime ranges
+                result = f'{result}{label}: {value}\n'
+        except AttributeError:
+            values = self.params
 
-            value = Template("{{ value }}").render(Context({'value': value}))  # workaround for datetime ranges
-            result = f'{result}{label}: {value}\n'
+            for param, value in values.items():
+                result = f'{result}{param}: {value}\n'
 
         return result
 
@@ -204,15 +226,35 @@ class Export(AbstractExport):
         return '{} #{} ({})'.format(_('Export'), self.pk, name)
 
     def _get_base_url(self):
-        app_label = self.get_app_label()
-        url = reverse(f'{app_label}:{self.content_type.model}_list')
-        return url
+        try:
+            app_label = self.get_app_label()
+            url = reverse(f'{app_label}:{self.content_type.model}_list')
+            return url
+        except NoReverseMatch:
+            model = self.content_type.model_class()
+            instance = model(pk=1)
+            detail_url = instance.get_absolute_url()
+
+            from urllib.parse import urlsplit
+            parsed = urlsplit(detail_url)
+            try:
+                match = resolve(parsed.path)
+                to_be_reversed = "%s:%s" % (match.namespace, match.url_name) if match.namespace else match.url_name
+                list_url = to_be_reversed.replace('detail', 'list')
+                return reverse(list_url)
+            except (Resolver404, NoReverseMatch):
+                pass
+
+        return None
+        # return NotImplementedError()
 
     def get_items_url(self):
-        return f'{self._get_base_url()}?export={self.pk}'
+        base_url = self._get_base_url()
+        return f'{self._get_base_url()}?export={self.pk}' if base_url is not None else None
 
     def get_absolute_url(self):
-        return f'{self._get_base_url()}?{self.query_string}'
+        base_url = self._get_base_url()
+        return f'{self._get_base_url()}?{self.query_string}' if base_url is not None else None
 
     def get_app_label(self):
         if self.context in [self.CONTEXT_LIST, self.CONTEXT_DETAIL]:
